@@ -1,4 +1,4 @@
-#' Create the full sequence of values in a vector.
+#' Create the full sequence of values in a vector
 #'
 #' This is useful if you want to fill in missing values that should have
 #' been observed but weren't. For example, `full_seq(c(1, 2, 4, 6), 1)`
@@ -18,10 +18,17 @@ full_seq <- function(x, period, tol = 1e-6) {
 #' @export
 full_seq.numeric <- function(x, period, tol = 1e-6) {
   rng <- range(x, na.rm = TRUE)
-  if (any((x - rng[1]) %% period > tol)) {
+  if (any(((x - rng[1]) %% period > tol) &
+          (period - (x - rng[1]) %% period > tol))) {
     stop("`x` is not a regular sequence.", call. = FALSE)
   }
 
+  # in cases where the last element is within tolerance, pad it so that
+  #   the output length is correct
+  if (period - ((rng[2] - rng[1]) %% period) <= tol) {
+    rng[2] <- rng[2] + tol
+  }
+
   seq(rng[1], rng[2], by = period)
 }
 
